==> eli_4.4.0.orig.tar.gz: eli-4.4.0/Eli/pkg/maptool/ebnf/xcode.h <==
switch (CaseTbl[c = *p++]) {
case 0:	/* sentinel - probably EOB */
  if (c == '\0') {
    p = TokenStart = TokenEnd = auxNUL(TokenStart, 0);
    if (*p) extcode = NORETURN;
    else {
      p = TokenStart = TokenEnd = auxEOF(TokenStart, 0);
      if (*p) extcode = NORETURN;
      else { extcode = EOFTOKEN; EndOfText(p, 0, &extcode, v); }
    }
    goto done;
  } else {
    obstack_strgrow(Csm_obstk, "char '");
    obstack_cchgrow(Csm_obstk, c);
    message(
      ERROR,
      (char *)obstack_strcpy(Csm_obstk, "' is not a token"),
      0,
      &curpos);
    continue;
  }
  
case 1:	/* space */
  while (scanTbl[c = *p++] & 1<<0) ;
  --p;
  continue;
case 2:	/* tab */
  do { StartLine -= TABSIZE(p - StartLine); }
  while (scanTbl[c = *p++] & 1<<1);
  --p;
  continue;
case 3:	/* newline */
  do { LineNum++; } while (scanTbl[c = *p++] & 1<<2);
  StartLine = --p - 1;
  continue;

case 4:	/* Entered on:  A-Z _ a-z */
	St_17:
		if( scanTbl[(c= *p++)+0] & 1<< 3){ /*  0-9 A-Z _ a-z */
			goto St_23;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 2;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;
			}

case 5:	/* Entered on: | */
	St_20:
		if((c= *p++) =='|') {			goto St_24;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 7;
			goto done;
			}

case 6:	/* Entered on: : */
	St_15:
		if((c= *p++) ==':') {		extcode = 4;/* remember fallback*/
		TokenEnd = p-1;

		scan = NULL;
		proc = NULL;
			goto St_22;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 4;
			goto done;
			}

case 7:	/* Entered on: / */
	St_14:
		if((c= *p++) =='/') {			goto St_21;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 6;
			goto done;
			}

case 8:	/* Entered on: ' */
	St_8:
			TokenEnd=p=auxPascalString(TokenStart, p-TokenStart);
			extcode = 19;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;

case 9:	/* Entered on: % */
	St_6:
			TokenEnd=p=auxEOL(TokenStart, p-TokenStart);
			extcode = 15001;
			goto done;

case 10:	/* Entered on: # */
	St_4:
			TokenEnd=p=auxEOL(TokenStart, p-TokenStart);
			extcode = 15001;
			goto done;


default: TokenEnd=p; extcode=ExtCodeTbl[c]; goto done; /*  $ & (-+ . @ [ ] */
}
	St_21:
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 8;
			goto done;
	St_22:
		if((c= *p++) =='=') {			goto St_25;}
		else {--p; goto fallback; }
	St_25:
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 5;
			goto done;
	St_24:
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 9;
			goto done;
	St_23:
		/*  0-9 A-Z _ a-z*/
		while(scanTbl[(c= *p++)+0] & 1<< 3);--p;
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 2;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;

==> eli-4.4.3.tar.gz: eli-4.4.3/Eli/pkg/maptool/ebnf/xcode.h <==
switch (CaseTbl[c = *p++]) {
case 0:	/* sentinel - probably EOB */
  if (c == '\0') {
    p = TokenStart = TokenEnd = auxNUL(TokenStart, 0);
    if (*p) extcode = NORETURN;
    else {
      p = TokenStart = TokenEnd = auxEOF(TokenStart, 0);
      if (*p) extcode = NORETURN;
      else { extcode = EOFTOKEN; EndOfText(p, 0, &extcode, v); }
    }
    goto done;
  } else {
    obstack_grow(Csm_obstk, "char '", 6);
    obstack_cchgrow(Csm_obstk, c);
    message(
      ERROR,
      (char *)obstack_copy0(Csm_obstk, "' is not a token", 16),
      0,
      &curpos);
    TokenEnd = p;
    continue;
  }
  
case 1:	/* space */
  while (scanTbl[c = *p++] & 1<<0) ;
  TokenEnd = p - 1;
  continue;
case 2:	/* tab */
  do { StartLine -= TABSIZE(p - StartLine); }
  while (scanTbl[c = *p++] & 1<<1);
  TokenEnd = p - 1;
  continue;
case 4:	/* carriage return */
  if (*p == '\n') { TokenEnd = p; continue; }
case 3:	/* newline */
  do { LineNum++; } while (scanTbl[c = *p++] & 1<<2);
  StartLine = (TokenEnd = p - 1) - 1;
  continue;

case 5:	/* Entered on:  A-Z _ a-z */
	St_17:
		if( scanTbl[(c= *p++)+0] & 1<< 3){ /*  0-9 A-Z _ a-z */
			goto St_23;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 10;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;
			}

case 6:	/* Entered on: | */
	St_20:
		if((c= *p++) =='|') {			goto St_21;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 5;
			goto done;
			}

case 7:	/* Entered on: : */
	St_15:
		if((c= *p++) ==':') {		extcode = 11;/* remember fallback*/
		TokenEnd = p-1;

		scan = NULL;
		proc = NULL;
			goto St_22;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 11;
			goto done;
			}

case 8:	/* Entered on: / */
	St_14:
		if((c= *p++) =='/') {			goto St_21;}
		else {
			TokenEnd= (--p); /* FINAL, no auxscan, must set */
			extcode = 5;
			goto done;
			}

case 9:	/* Entered on: ' */
	St_8:
			TokenEnd=p=auxPascalString(TokenStart, p-TokenStart);
			extcode = 16;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;

case 10:	/* Entered on: % */
	St_6:
			TokenEnd=p=auxEOL(TokenStart, p-TokenStart);
			extcode = 15001;
			goto done;

case 11:	/* Entered on: # */
	St_4:
			TokenEnd=p=auxEOL(TokenStart, p-TokenStart);
			extcode = 15001;
			goto done;


default: TokenEnd=p; extcode=ExtCodeTbl[c]; goto done; /*  $ & (-+ . @ [ ] */
}
	St_21:
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 2;
			goto done;
	St_22:
		if((c= *p++) =='=') {			goto St_24;}
		else {--p; goto fallback; }
	St_24:
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 11;
			goto done;
	St_23:
		/*  0-9 A-Z _ a-z*/
		while(scanTbl[(c= *p++)+0] & 1<< 3);--p;
			TokenEnd= p; /* FINAL, no auxscan, must set */
			extcode = 10;
			mkidn(TokenStart, TokenEnd-TokenStart,&extcode,v);
			goto done;
